import 'package:connect_flutter/auth/signin.dart';
import 'package:connect_flutter/auth/signup.dart';
import 'package:connect_flutter/error/error.dart';
import 'package:connect_flutter/main/main_screen.dart';
import 'package:connect_flutter/service/softcorp_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_spinner/default_spinner.dart';
import 'package:dart_softcorp/softcorp.pbgrpc.dart' as SoftcorpGrpc;
import 'dart:html' as html;

import 'package:softcorp_flutter_core/responsive/responsive.dart';

enum AuthStatus {
  signIn,
  signUp,
}

class AuthScreen extends StatefulWidget {
  final String loginChallenge;

  const AuthScreen({
    Key? key,
    required this.loginChallenge,
  }) : super(key: key);

  @override
  State<AuthScreen> createState() {
    return _AuthScreenState();
  }
}

class _AuthScreenState extends State<AuthScreen> {
  late Future<SoftcorpGrpc.AuthPublicResponse> validateLoginChallenge;

  @override
  void initState() {
    validateLoginChallenge = SoftcorpService.validateLoginChallenge(
            loginChallenge: widget.loginChallenge)
        .catchError((onError) {
      Navigator.of(context).pushReplacement(
          MaterialPageRoute(builder: (context) => const ErrorScreen()));
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: validateLoginChallenge,
      builder: (BuildContext futureContext,
          AsyncSnapshot<SoftcorpGrpc.AuthPublicResponse> snapshot) {
        switch (snapshot.connectionState) {
          case ConnectionState.done:
            if (snapshot.hasError ||
                !snapshot.hasData ||
                snapshot.data == null) {
              return const DefaultSpinner(
                backgroundColor: Colors.transparent,
                size: 150,
              );
            }
            if (snapshot.data!.redirectAddr != "") {
              html.window.location.href = snapshot.data!.redirectAddr;
            }
            return AuthSwitchScreen(
              loginChallenge: widget.loginChallenge,
              app: snapshot.data == null ? null : snapshot.data!.client,
            );
          default:
            return const DefaultSpinner(
              backgroundColor: Colors.transparent,
              size: 150,
            );
        }
      },
    );
  }
}

class AuthSwitchScreen extends StatefulWidget {
  final SoftcorpGrpc.ClientApp? app;
  final String loginChallenge;
  final bool? previewMode;

  const AuthSwitchScreen(
      {Key? key,
      required this.app,
      required this.loginChallenge,
      this.previewMode})
      : super(key: key);

  @override
  State<AuthSwitchScreen> createState() {
    return _AuthSwitchScreenState();
  }
}

class _AuthSwitchScreenState extends State<AuthSwitchScreen> {
  AuthStatus authStatus = AuthStatus.signIn;

  changeScreen() {
    AuthStatus newAuthStatus = AuthStatus.signIn;
    if (authStatus == AuthStatus.signIn) {
      newAuthStatus = AuthStatus.signUp;
    }
    setState(() {
      authStatus = newAuthStatus;
    });
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      constraints: BoxConstraints(minHeight: size.height),
      child: MainScreen(
        compactRightHeight: 650,
        compactLeftHeight: 400,
        rightChild: Container(
          constraints: Responsive.isMobile(context) ? null : BoxConstraints(minHeight: size.height),
          child: AnimatedSwitcher(
            duration: const Duration(milliseconds: 500),
            transitionBuilder: (Widget child, Animation<double> animation) {
              return ScaleTransition(child: child, scale: animation);
            },
              child: authStatus == AuthStatus.signIn
                  ? SignInScreen(
                      previewMode: widget.previewMode,
                      changeScreen: changeScreen,
                      loginChallenge: widget.loginChallenge,
                      app: widget.app,
                    )
                  : SignUpScreen(
                      changeScreen: changeScreen,
                      loginChallenge: widget.loginChallenge,
                    ),
          ),
        ),
      ),
    );
  }
}
