import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/default_dropdown_field/default_dropdown_field.dart';
import 'package:softcorp_flutter_core/default_form_field/default_form_field.dart';
import 'package:websafe_svg/websafe_svg.dart';

class SignUpScreen extends StatelessWidget {
  final Function changeScreen;
  final String loginChallenge;

  const SignUpScreen({
    Key? key,
    required this.changeScreen,
    required this.loginChallenge,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(defaultPadding),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          SizedBox(
            height: 70,
            child: WebsafeSvg.asset(
              "assets/logos/connect-color.svg",
            ),
          ),
          const SizedBox(height: defaultPadding * 2),
          const Text(
            "Create a Softcorp Connect account",
            style: TextStyle(
              color: defaultTitleColor,
              fontSize: 25,
              fontWeight: FontWeight.w400,
              overflow: TextOverflow.ellipsis,
            ),
          ),
          const SizedBox(height: defaultPadding * 2),
          SizedBox(
            width: 500,
            child: DefaultFormField(
              textEditingController: TextEditingController(),
              textInputType: TextInputType.emailAddress,
              hint: "Enter your email address",
              label: "Email",
              prefixIcon: Icons.email_rounded,
              addDefaultBorder: true,
            ),
          ),
          SizedBox(
            width: 500,
            child: DefaultFormField(
              textEditingController: TextEditingController(),
              textInputType: TextInputType.text,
              hint: "Enter your password",
              prefixIcon: Icons.lock_rounded,
              label: "Password",
              addDefaultBorder: true,
              obscureText: true,
            ),
          ),
          SizedBox(
            width: 500,
            child: DefaultDropdownFormField(
              label: "Gender",
              prefixIcon: Icons.person_rounded,
              addDefaultBorder: true,
              onChanged: (String? value) {},
              items: const ["Male", "Female", "Other"],
              hint: "Chose a gender",
            ),
          ),
          const SizedBox(height: defaultPadding * 2),
          SizedBox(
            height: 45,
            child: ElevatedButton.icon(
              icon: const Icon(
                Icons.person_add_alt_1_rounded,
                size: 18,
                color: Colors.white,
              ),
              style: ButtonStyle(
                backgroundColor: MaterialStateProperty.resolveWith<Color>(
                  (Set<MaterialState> states) {
                    if (states.contains(MaterialState.pressed)) {
                      return Colors.black54;
                    }
                    return Colors.black; // Use the component's default.
                  },
                ),
              ),
              onPressed: () {},
              label: const Text('Identify and create account'),
            ),
          ),
          const SizedBox(height: 10),
          TextButton(
            onPressed: () {
              changeScreen();
            },
            child: const Text(
              "Already have an account? Sign in.",
              textAlign: TextAlign.left,
              style: TextStyle(
                color: defaultPrimaryColor,
                fontWeight: FontWeight.w400,
              ),
            ),
          ),
        ],
      ),
    );
  }
}
