import 'package:connect_flutter/error/error.dart';
import 'package:connect_flutter/main/main_screen.dart';
import 'package:connect_flutter/service/softcorp_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/default_spinner/default_spinner.dart';
import 'package:dart_softcorp/softcorp.pbgrpc.dart' as SoftcorpGrpc;
import 'package:softcorp_flutter_core/responsive/responsive.dart';
import 'dart:html' as html;

import 'about_client.dart';
import 'consent_info.dart';

class ConsentScreen extends StatefulWidget {
  final String consentChallenge;
  final bool? previewMode;

  const ConsentScreen(
      {Key? key, required this.consentChallenge, this.previewMode})
      : super(key: key);

  @override
  State<ConsentScreen> createState() {
    return _ConsentScreenState();
  }
}

class _ConsentScreenState extends State<ConsentScreen> {
  late Future<SoftcorpGrpc.AuthPublicResponse> validateConsentChallenge;

  @override
  void initState() {
    validateConsentChallenge = SoftcorpService.validateConsentChallenge(
            consentChallenge: widget.consentChallenge)
        .catchError((onError) {
      Navigator.of(context).pushReplacement(
          MaterialPageRoute(builder: (context) => const ErrorScreen()));
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return FutureBuilder(
      future: validateConsentChallenge,
      builder: (BuildContext futureContext,
          AsyncSnapshot<SoftcorpGrpc.AuthPublicResponse> snapshot) {
        switch (snapshot.connectionState) {
          case ConnectionState.done:
            if (snapshot.hasError ||
                !snapshot.hasData ||
                snapshot.data == null) {
              return const DefaultSpinner(
                backgroundColor: Colors.transparent,
                size: 150,
              );
            }
            if (snapshot.data != null && snapshot.data!.redirectAddr != "") {
              html.window.location.href = snapshot.data!.redirectAddr;
            }
            return ConsentScreenBuilder(
              height: size.height,
              consentChallenge: widget.consentChallenge,
              app: snapshot.data!.client,
              nameOfUser: snapshot.data!.nameOfUser,
              previewMode: widget.previewMode,
            );
          default:
            return const DefaultSpinner(
              backgroundColor: Colors.transparent,
              size: 150,
            );
        }
      },
    );
  }
}

class ConsentScreenBuilder extends StatelessWidget {
  final bool? previewMode;
  final SoftcorpGrpc.ClientApp app;
  final String nameOfUser;
  final String consentChallenge;
  final double height;

  const ConsentScreenBuilder(
      {Key? key,
      required this.height,
      required this.app,
      required this.nameOfUser,
      required this.consentChallenge,
      this.previewMode})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MainScreen(
      compactRightHeight: 550,
      compactLeftHeight: 600,
      rightChild: Container(
        constraints: Responsive.isMobile(context)
            ? null
            : BoxConstraints(minHeight: height),
        child: ConsentInfo(
          previewMode: previewMode,
          app: app,
          nameOfUser: nameOfUser,
          consentChallenge: consentChallenge,
        ),
      ),
      leftChild: Padding(
        padding: const EdgeInsets.only(
            left: defaultPadding,
            right: defaultPadding,
            bottom: defaultPadding * 4),
        child: AboutClient(
          app: app,
        ),
      ),
    );
  }
}
