import 'package:cached_network_image/cached_network_image.dart';
import 'package:connect_flutter/service/softcorp_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:progress_state_button/iconed_button.dart';
import 'package:progress_state_button/progress_button.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:dart_softcorp/softcorp.pbgrpc.dart' as SoftcorpGrpc;
import 'package:softcorp_flutter_core/default_spinner/default_spinner.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';
import 'package:websafe_svg/websafe_svg.dart';
import 'dart:html' as html;

class ConsentInfo extends StatefulWidget {
  final String nameOfUser;
  final String consentChallenge;
  final SoftcorpGrpc.ClientApp app;
  final bool? previewMode;

  const ConsentInfo(
      {Key? key,
      required this.nameOfUser,
      required this.app,
      required this.previewMode,
      required this.consentChallenge})
      : super(key: key);

  @override
  State<ConsentInfo> createState() {
    return _ConsentInfoState(
    );
  }
}

class _ConsentInfoState extends State<ConsentInfo> {
  ButtonState buttonStateAllow = ButtonState.idle;
  ButtonState buttonStateCancel = ButtonState.idle;

  List<String> getScopeString(SoftcorpGrpc.Scope scope) {
    List<String> scopeString = [];
    if (scope.readBirthday) {
      scopeString.add(" birthday,");
    }
    if (scope.readEmail) {
      scopeString.add(" email,");
    }
    if (scope.readId) {
      scopeString.add(" user-id,");
    }
    if (scope.readName) {
      scopeString.add(" name,");
    }
    if (scope.offlineAccess) {
      scopeString.add(" information again in the future,");
    }
    if (scope.readCreatedAt) {
      scopeString.add(" profile creation date,");
    }
    if (scope.readSsn) {
      scopeString.add(" social security number,");
    }
    if (scope.readCountry) {
      scopeString.add(" country of origin,");
    }
    if (scope.readGender) {
      scopeString.add(" gender,");
    }
    if (scope.readPrefLangauge) {
      scopeString.add(" preferred language,");
    }
    scopeString.last =
        scopeString.last.substring(0, scopeString.last.length - 1);
    return scopeString;
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Padding(
      padding: const EdgeInsets.only(
          left: defaultPadding * 2,
          right: defaultPadding * 2,
          bottom: defaultPadding * 2),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          SizedBox(
            height: 60,
            child: CachedNetworkImage(
              height: 60,
              imageUrl: widget.app.logoUrl,
              progressIndicatorBuilder: (context, url, downloadProgress) =>
                  const Center(
                child: DefaultSpinner(
                  backgroundColor: Colors.transparent,
                  size: 60,
                ),
              ),
              errorWidget: (context, url, error) => WebsafeSvg.network(
                widget.app.logoUrl,
              ),
            ),
          ),
          const SizedBox(height: defaultPadding),
          Text(
            "Hi " + widget.nameOfUser,
            style: const TextStyle(
              color: defaultTitleColor,
              fontWeight: FontWeight.w500,
              fontSize: 24,
            ),
          ),
          const SizedBox(height: defaultPadding),
          Text(
            "Will you allow " + widget.app.name + " to read your:",
            style: const TextStyle(
              color: defaultTitleColor,
              fontWeight: FontWeight.w400,
              fontSize: 18,
            ),
          ),
          const SizedBox(height: defaultPadding),
          ListView.builder(
            shrinkWrap: true,
            itemCount: widget.app.scopes.length,
            itemBuilder: (context, index) {
              SoftcorpGrpc.Scope scope = widget.app.scopes[index];
              List<String> scopeString = getScopeString(scope);
              return Container(
                margin: const EdgeInsets.only(top: 10, bottom: 10),
                width: size.width / 3,
                child: Wrap(
                  direction: Axis.horizontal,
                  children: [
                    const Icon(
                      Icons.info_outline_rounded,
                      color: defaultSubTitleColor,
                      size: 24,
                    ),
                    const SizedBox(width: 5),
                    Text(
                      scope.name + ":",
                      style: const TextStyle(
                        color: defaultSubTitleColor,
                        fontSize: 16,
                      ),
                    ),
                    Wrap(
                      direction: Axis.horizontal,
                      children: scopeString.map((scopeAllowance) {
                        return Text(
                          scopeAllowance,
                          style: const TextStyle(
                            color: defaultSubTitleColor,
                            fontSize: 16,
                          ),
                        );
                      }).toList(),
                    ),
                  ],
                ),
              );
            },
          ),
          SizedBox(
            width: Responsive.isMobile(context) ? size.width : size.width / 2,
            child: Wrap(
              direction: Axis.horizontal,
              runAlignment: WrapAlignment.spaceBetween,
              alignment: WrapAlignment.center,
              crossAxisAlignment: WrapCrossAlignment.center,
              spacing: 20,
              runSpacing: 20,
              children: [
                ProgressButton.icon(
                  height: 50,
                  iconedButtons: const {
                    ButtonState.idle: IconedButton(
                        text: "Cancel",
                        icon: Icon(Icons.cancel_rounded, color: Colors.white),
                        color: defaultDangerColor),
                    ButtonState.loading: IconedButton(
                        text: "Loading", color: defaultPrimaryColor),
                    ButtonState.fail: IconedButton(
                        text: "Failure",
                        icon: Icon(Icons.cancel, color: Colors.white),
                        color: defaultDangerColor),
                    ButtonState.success: IconedButton(
                      text: "Success",
                      icon: Icon(
                        Icons.check_circle,
                        color: Colors.white,
                      ),
                      color: defaultSuccessColor,
                    )
                  },
                  onPressed: () {
                    if (widget.previewMode == true || buttonStateAllow != ButtonState.idle || buttonStateCancel != ButtonState.idle ) {
                      return;
                    }
                    setState(() {
                      buttonStateCancel = ButtonState.loading;
                    });
                    SoftcorpService.giveConsent(
                            consentChallenge: widget.consentChallenge, consent: false)
                        .catchError((onError) {
                      setState(() {
                        buttonStateCancel = ButtonState.fail;
                      });
                      Future.delayed(Duration(seconds: 2)).then((value) {
                        setState(() {
                          buttonStateCancel = ButtonState.idle;
                        });
                      });
                    }).then((value) {
                      setState(() {
                        buttonStateCancel = ButtonState.success;
                      });
                      Future.delayed(const Duration(seconds: 2)).then((_) {
                        html.window.location.href = value.redirectAddr;
                      });
                    });
                  },
                  state: buttonStateCancel,
                  radius: defaultCornerRadius,
                ),
                ProgressButton.icon(
                  height: 50,
                  iconedButtons: const {
                    ButtonState.idle: IconedButton(
                        text: "Accept",
                        icon: Icon(Icons.check_rounded, color: Colors.white),
                        color: defaultPrimaryColor),
                    ButtonState.loading: IconedButton(
                        text: "Loading", color: defaultPrimaryColor),
                    ButtonState.fail: IconedButton(
                        text: "Failure",
                        icon: Icon(Icons.cancel, color: Colors.white),
                        color: defaultDangerColor),
                    ButtonState.success: IconedButton(
                        text: "Success",
                        icon: Icon(
                          Icons.check_circle,
                          color: Colors.white,
                        ),
                        color: defaultSuccessColor)
                  },
                  onPressed: () {
                    if (widget.previewMode == true || buttonStateCancel != ButtonState.idle || buttonStateAllow != ButtonState.idle) {
                      return;
                    }
                    setState(() {
                      buttonStateAllow = ButtonState.loading;
                    });
                    SoftcorpService.giveConsent(
                            consentChallenge: widget.consentChallenge, consent: true)
                        .catchError((onError) {
                      setState(() {
                        buttonStateAllow = ButtonState.fail;
                      });
                      Future.delayed(const Duration(seconds: 2)).then((value) {
                        setState(() {
                          buttonStateAllow = ButtonState.idle;
                        });
                      });
                    }).then((value) {
                      setState(() {
                        buttonStateAllow = ButtonState.success;
                      });
                      Future.delayed(const Duration(seconds: 2)).then((_) {
                        html.window.location.href = value.redirectAddr;
                      });
                    });
                  },
                  state: buttonStateAllow,
                  radius: defaultCornerRadius,
                ),
                if (!Responsive.isMobile(context)) const SizedBox(height: 200),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
