import 'package:connect_flutter/auth/auth.dart';
import 'package:connect_flutter/consent/consent.dart';
import 'package:connect_flutter/service/softcorp_service.dart';
import 'package:flutter/material.dart';
import 'package:url_strategy/url_strategy.dart';
import 'error/error.dart';
import 'dart:html' as html;

void main() async {
  await SoftcorpService.connectGrpcServices();
  setPathUrlStrategy();
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      onGenerateRoute: (settings) {
        switch (Uri.base.path) {
          case "/":
            return MaterialPageRoute(builder: (BuildContext context) {
              return ErrorScreen();
            });
          case "/error":
            return MaterialPageRoute(builder: (BuildContext context) {
              return ErrorScreen();
            });
          case "/login":
            String? loginChallenge =
                Uri.base.queryParameters["login_challenge"];
            if (loginChallenge == null || loginChallenge == "") {
              html.window.location.replace("/error");
            }
            return MaterialPageRoute(builder: (BuildContext context) {
              return AuthScreen(
                loginChallenge: loginChallenge ?? "",
              );
            });
          case "/consent":
            String? consentChallenge =
                Uri.base.queryParameters["consent_challenge"];
            if (consentChallenge == null || consentChallenge == "") {
              html.window.location.replace("/error");
            }
            return MaterialPageRoute(builder: (BuildContext context) {
              return ConsentScreen(
                consentChallenge: consentChallenge ?? "",
              );
            });
          default:
            return MaterialPageRoute(builder: (BuildContext context) {
              return ErrorScreen();
            });
        }
      },
      title: 'Softcorp Connect',
      debugShowCheckedModeBanner: false,
    );
  }
}
