import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/footer/default_footer.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';
import 'package:softcorp_flutter_core/split_screen/split_screen.dart';
import 'package:websafe_svg/websafe_svg.dart';

import 'footer.dart';

class MainScreen extends StatelessWidget {
  final Widget? leftChild;
  final Widget? rightChild;
  final double compactLeftHeight;
  final double compactRightHeight;

  const MainScreen(
      {Key? key,
      this.leftChild,
      this.rightChild,
      required this.compactLeftHeight,
      required this.compactRightHeight})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return SplitScreen(
      compactRightHeight: compactRightHeight,
      logoSize: 120,
      compactLeftHeight: compactLeftHeight,
      footerSize: size.height < 700 ? 0 : 100,
      backgroundColor: Colors.white,
      leftCornerLogoNeutral: Column(
        children: <Widget>[
          WebsafeSvg.asset(
            "assets/logos/connect-color.svg",
            width: 50,
          ),
          const SizedBox(height: 5),
          Text(
            "Connect",
            style: TextStyle(
              color: Responsive.isMobile(context)
                  ? defaultTitleColor
                  : secondaryBodyColor,
              fontSize: 22,
              fontWeight: FontWeight.w600,
            ),
          ),
        ],
      ),
      leftCornerLogoColor: Column(
        children: <Widget>[
          WebsafeSvg.asset(
            "assets/logos/connect-color.svg",
            width: 50,
          ),
          const SizedBox(height: 5),
          Text(
            "Connect",
            style: TextStyle(
              color: Responsive.isMobile(context)
                  ? defaultTitleColor
                  : secondaryBodyColor,
              fontSize: 22,
              fontWeight: FontWeight.w600,
            ),
          ),
        ],
      ),
      leftChild: leftChild ??
          Center(
            child: Container(
              width: size.width,
              margin: const EdgeInsets.only(bottom: defaultPadding*4, right: defaultPadding, left: defaultPadding),
              alignment: Alignment.center,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                children: const [
                  Text(
                    "Softcorp Connect will securely authenticate your credentials",
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        color: Colors.white,
                        fontSize: 25,
                        fontWeight: FontWeight.w400),
                  ),
                  SizedBox(
                    height: defaultPadding,
                  ),
                  Text(
                    "You can view and manage who and what data you have given access to afterwards through our mobile application",
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        color: Colors.white60,
                        fontSize: 18,
                        fontWeight: FontWeight.w400),
                  ),
                ],
              ),
            ),
          ),
      rightChild: rightChild,
      footer: const SizedBox(
        height: 100,
        child: DefaultSoftcorpFooter(),
      ),
    );
  }
}
