import 'package:dart_softcorp/google/protobuf/timestamp.pb.dart';
import 'package:dart_softcorp/softcorp.pbgrpc.dart' as SoftcorpGrpc;

List<SoftcorpGrpc.Scope> mockScopes = [
  SoftcorpGrpc.Scope()
    ..name = "Scope 1"
    ..readPrefLangauge = true
    ..readGender = true
    ..readCountry = true
    ..scopeType = SoftcorpGrpc.ScopeType.USER_DETAILS,
  SoftcorpGrpc.Scope()
    ..name = "Scope 2"
    ..readName = true
    ..readSsn = true
    ..offlineAccess = true
    ..scopeType = SoftcorpGrpc.ScopeType.USER_IDENTITY,
  SoftcorpGrpc.Scope()
    ..name = "Scope 3"
    ..readGender = true
    ..scopeType = SoftcorpGrpc.ScopeType.OFFLINE_ACCESS,
];
List<SoftcorpGrpc.Grant> mockGrants = [
  SoftcorpGrpc.Grant()
    ..name = "Grant 1"
    ..grantType = SoftcorpGrpc.GrantType.REFRESH_GRANT
];

List<SoftcorpGrpc.OauthResponse> mocResponses = [
  SoftcorpGrpc.OauthResponse()
    ..name = "Response 1"
    ..responseType = SoftcorpGrpc.ResponeType.ID_RESPONSE,
];

SoftcorpGrpc.ClientApp mockApp = SoftcorpGrpc.ClientApp(
  name: "Mock Name",
  createdAt: Timestamp.fromDateTime(DateTime.now()),
  updatedAt: Timestamp.fromDateTime(DateTime.now()),
  id: "mock id",
  contactEmail: "mock@softcorp.io",
  ownerId: "mock-owner-id",
  appWebsite: "https://mock.softcorp.io",
  logoUrl: "http://softcorp.io/wp-content/uploads/2021/10/softcorp-color.svg",
  termsUrl: "https://mock.softcorp.io/terms",
  about:
      "At Text we want to publish books that make a difference to people’s lives. We believe that reading should be a marvellous experience, that every book you read should somehow change your life if only by a fraction. We love the phrase ‘lost in a book’—that’s where we want our readers to be. You can’t get lost in a newspaper or a magazine or even a movie. But people get lost in books every day—on the tram, on the beach, in bed. Reading is what keeps the imagination supple and challenges preconceptions and prejudices. You read at your own speed, and the world you enter courtesy of the writer is yours and yours only, even if the person next to you on the bus is reading exactly the same book.",
  audience: ["test mock audience"],
  scopes: mockScopes,
  grants: mockGrants,
  responses: mocResponses,
  callbacks: ["http://callback1.com"],
  availableGrants: mockGrants,
  availableScopes: mockScopes,
  availableResponses: mocResponses,
);

class ConnectService {
  final SoftcorpGrpc.ConnectAuthPublicServiceClient client;
  final bool? testMode;
  final bool? mockMode;

  ConnectService({required this.client, this.testMode, this.mockMode}) {
    if (mockMode == true && testMode == false) {
      throw Exception("in order for mock mode to be enabled, enable test mode");
    }
  }

  Future<SoftcorpGrpc.AuthPublicResponse> validateLoginChallenge(
      {required String challenge}) async {
    if (testMode == true) {
      print("validateLoginChallenge");
    }
    if (mockMode == true) {
      return await Future.delayed(const Duration(seconds: 2)).then((_) {
        return SoftcorpGrpc.AuthPublicResponse()..client = mockApp;
      });
    }
    SoftcorpGrpc.AuthPublicRequest req = SoftcorpGrpc.AuthPublicRequest();
    req.challenge = challenge;
    return client.validateLoginChallenge(req);
  }

  Future<SoftcorpGrpc.AuthPublicResponse> validateUserCredentials(
      {required String challenge,
      required String email,
      required String password}) async {
    if (testMode == true) {
      print("validateUserCredentials");
    }
    if (mockMode == true) {
      return await Future.delayed(const Duration(seconds: 2)).then((_) {
        return SoftcorpGrpc.AuthPublicResponse()
          ..redirectAddr =
              "http://localhost:3050/consent?consent_challenge=1234";
      });
    }
    SoftcorpGrpc.AuthPublicRequest req = SoftcorpGrpc.AuthPublicRequest();
    req.challenge = challenge;
    req.password = password;
    req.email = email;
    return client.validateUserCredentials(req);
  }

  Future<SoftcorpGrpc.AuthPublicResponse> validateConsentChallenge(
      {required String challenge}) async {
    if (testMode == true) {
      print("validateConsentChallenge");
    }
    if (mockMode == true) {
      return await Future.delayed(const Duration(seconds: 2)).then((_) {
        return SoftcorpGrpc.AuthPublicResponse()
          ..nameOfUser = "mock-user@softcorp.io"
          ..client = mockApp;
      });
    }
    SoftcorpGrpc.AuthPublicRequest req = SoftcorpGrpc.AuthPublicRequest();
    req.challenge = challenge;
    return client.validateConsentChallenge(req);
  }

  Future<SoftcorpGrpc.AuthPublicResponse> giveConsent(
      {required String challenge, required bool consent}) async {
    if (testMode == true) {
      print("giveConsent");
    }
    if (mockMode == true) {
      return await Future.delayed(const Duration(seconds: 2)).then((_) {
        return SoftcorpGrpc.AuthPublicResponse()
          ..redirectAddr = "http://localhost:3050/success";
      });
    }
    SoftcorpGrpc.AuthPublicRequest req = SoftcorpGrpc.AuthPublicRequest();
    req.challenge = challenge;
    req.consent = consent;
    return client.giveConsent(req);
  }
}
