import 'package:grpc/grpc_web.dart';
import 'connect_service.dart';
import 'package:dart_softcorp/softcorp.pbgrpc.dart' as SoftcorpGrpc;

class SoftcorpService {
  static ConnectService? connectService;

  static Future<void> connectGrpcServices() async {
    var connectWebChannel = GrpcWebClientChannel.xhr(
        Uri.parse("https://api.connect.softcorp.io:443"));
    connectService = ConnectService(
      client: SoftcorpGrpc.ConnectAuthPublicServiceClient(connectWebChannel),
      testMode: false,
      mockMode: false,
    );
  }

  static checkServices() {
    if (connectService == null) {
      throw Exception("Connect service not initialized");
    }
  }

  static applyTest() async {
    //await Future.delayed(Duration(seconds: 5));
  }

  static Future<SoftcorpGrpc.AuthPublicResponse> validateLoginChallenge(
      {required String loginChallenge}) async {
    checkServices();
    await applyTest();
    if (loginChallenge == "") {
      throw Exception("invalid login challenge");
    }
    return connectService!.validateLoginChallenge(challenge: loginChallenge);
  }

  static Future<SoftcorpGrpc.AuthPublicResponse> validateUserCredentials(
      {required String loginChallenge,
      required String email,
      required String password}) async {
    checkServices();
    await applyTest();
    if (loginChallenge == "") {
      throw Exception("invalid login challenge");
    }
    if (email == "" || password == "") {
      throw Exception("invalid email or password");
    }
    return connectService!.validateUserCredentials(
        challenge: loginChallenge, email: email, password: password);
  }

  static Future<SoftcorpGrpc.AuthPublicResponse> validateConsentChallenge(
      {required String consentChallenge}) async {
    checkServices();
    await applyTest();
    if (consentChallenge == "") {
      throw Exception("invalid consent challenge");
    }
    return connectService!
        .validateConsentChallenge(challenge: consentChallenge);
  }

  static Future<SoftcorpGrpc.AuthPublicResponse> giveConsent(
      {required String consentChallenge, required bool consent}) async {
    checkServices();
    await applyTest();
    if (consentChallenge == "") {
      throw Exception("invalid consent challenge");
    }
    return connectService!
        .giveConsent(challenge: consentChallenge, consent: consent);
  }
}
